"""Fix CARTA correction for real

Revision ID: 8a027ec917ff
Revises: 77d7ee198d7a
Create Date: 2021-09-21 16:09:51.557461

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.sql import table, column
from sqlalchemy import String, LargeBinary


# revision identifiers, used by Alembic.
revision = '8a027ec917ff'
down_revision = '77d7ee198d7a'
branch_labels = None
depends_on = None


workflow_templates = table('workflow_templates',
                           column('filename', String()),
                           column('content', LargeBinary())
                           )

script_content = b"""#!/bin/sh
set -o errexit

export HOME=$TMPDIR
{{#remote-cv}}
export CAPO_PATH=$(readlink -f $TMPDIR)
export CAPO_PROFILE={{profile}}
{{/remote-cv}}
fetch_foundation(){
  ../productfetcher{{product_locator}}

  echo "Moving images out of subdirectories...."
  for dir in *.fits; do mv $dir $dir.1; done;

  find . -mindepth 1 -type f -print -exec mv {} . \\;
  find . -mindepth 1 -type d -empty -delete
  echo "Done. Ready for Carta!"
}


{{#need_data}}
./framework.sh -r .
chmod 770 .
cd rawdata/

fetch_foundation {{^single_image}}&{{/single_image}}

.{{/need_data}}./carta_envoy {{#need_data}}--parallel{{/need_data}} {{#single_image}}--single -i {{imageName}}{{/single_image}} -d $1 -n $2 -wf $3 -r $4
{{#need_data}}wait{{/need_data}}
"""

condor_content = b"""executable = carta.sh
arguments = {{source_dir}} {{user_email}} {{request_id}} {{notify_ready}}

output = carta.out
error = carta.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/carta_envoy{{#remote-cv}}, {{profile}}.properties{{/remote-cv}}
{{#need_data}}transfer_output_files = rawdata{{/need_data}}

request_memory = {{ramInGb}}
getenv = True
{{^remote-cv}}
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True
{{/remote-cv}}
{{#remote-cv}}
requirements = HasLustre == True && (CVPOST == True)
+partition = "CVPOST"
{{/remote-cv}}

queue
"""

old_script = b"""#!/bin/sh
set -o errexit

export HOME=$TMPDIR

fetch_foundation(){
  ../productfetcher{{product_locator}}

  echo "Moving images out of subdirectories...."
  for dir in *.fits; do mv $dir $dir.1; done;

  find . -mindepth 1 -type f -print -exec mv {} . \;
  find . -mindepth 1 -type d -empty -delete
  echo "Done. Ready for Carta!"
}


{{#need_data}}
./framework.sh -r .
chmod 770 .
cd rawdata/

fetch_foundation {{^single_image}}&{{/single_image}}

.{{/need_data}}./carta_envoy {{#need_data}}--parallel{{/need_data}} {{#single_image}}--single -i {{imageName}}{{/single_image}} -d $1 -n $2 -wf $3 -r $4
{{#need_data}}wait{{/need_data}}

"""

old_condor = b"""executable = carta.sh
arguments = {{source_dir}} {{user_email}} {{request_id}} {{notify_ready}}

output = carta.out
error = carta.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/carta_url_template.html, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/carta_envoy{{#remote-cv}}, {{profile}}.properties{{/remote-cv}}
{{#need_data}}transfer_output_files = rawdata{{/need_data}}

request_memory = {{ramInGb}}
getenv = True
{{^remote-cv}}
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True
{{/remote-cv}}
{{#remote-cv}}
environment = "CAPO_PATH=. CAPO_PROFILE={{profile}}"

requirements = HasLustre == True && (CVPOST == True)
+partition = "CVPOST"
{{/remote-cv}}

queue

"""


def upgrade():
    op.execute(workflow_templates.update()
               .where(workflow_templates.c.filename == op.inline_literal('carta.sh'))
               .values({'content': script_content}))
    op.execute(workflow_templates.update()
               .where(workflow_templates.c.filename == op.inline_literal('carta.condor'))
               .values({'content': condor_content}))


def downgrade():
    op.execute(workflow_templates.update()
               .where(workflow_templates.c.filename == op.inline_literal('carta.sh'))
               .values({'content': op.inline_literal(str(old_script))}))
    op.execute(workflow_templates.update()
               .where(workflow_templates.c.filename == op.inline_literal('carta.condor'))
               .values({'content': op.inline_literal(str(old_condor))}))
